@@ -1,12 +1,12 @@
 from circuitsvis.attention import attention_patterns
-import circuitsvis.render
+import circuitsvis.utils.render
 import numpy as np
 
 
 class TestAttention:
     def test_matches_snapshot(self, snapshot, monkeypatch):
         # Monkeypatch uuid4 to always return the same uuid
-        monkeypatch.setattr(circuitsvis.render, "uuid4", lambda: "mock")
+        monkeypatch.setattr(circuitsvis.utils.render, "uuid4", lambda: "mock")
 
         res = attention_patterns(
             tokens=["a", "b"],
